@@ -3,4 +3,4 @@
 __author__ = """Ilan Gold"""
 __email__ = 'ilan_gold@hms.harvard.edu'
 __version__ = '0.1.0'
-import generate_tiff_offsets, get_offsets
\ No newline at end of file
+from .generate_tiff_offsets import generate_tiff_offsets, get_offsets
\ No newline at end of file
